context("canvasXpress Web Charts - Sankey")


test_that("cXsankey1", {
    check_ui_test(cXsankey1())
})

test_that("cXsankey2", {
    check_ui_test(cXsankey2())
})

test_that("cXsankey3", {
    check_ui_test(cXsankey3())
})

test_that("cXsankey4", {
    check_ui_test(cXsankey4())
})

test_that("cXsankey5", {
    check_ui_test(cXsankey5())
})

test_that("cXsankey6", {
    check_ui_test(cXsankey6())
})
